@@ -20,6 +20,7 @@
 #' @param html_headers A character vector of column names to be used in the table. Defaults to \code{colnames}.
 #' @param html_change_col_name Name of the change column to use in the HTML table. Defaults to \code{chng_type}.
 #' @param html_group_col_name Name of the group column to be used in the table (if there are multiple grouping vars). Defaults to \code{grp}.
+#' @param round_output_to Number of digits to round the output to. Defaults to 3.
 #' @import dplyr
 #' @export
 #' @examples
@@ -33,7 +34,8 @@
 compare_df <- function(df_new, df_old, group_col, exclude = NULL, limit_html = 100, tolerance = 0, tolerance_type = 'ratio',
                        stop_on_error = TRUE, keep_unchanged = FALSE,
                        color_scheme = c("addition" = "green", "removal" = "red", "unchanged_cell" = "gray", "unchanged_row" = "deepskyblue"),
-                       html_headers = NULL, html_change_col_name = "chng_type", html_group_col_name = "grp"){
+                       html_headers = NULL, html_change_col_name = "chng_type", html_group_col_name = "grp",
+                       round_output_to = 3){
 
   both_tables = list(df_new = df_new, df_old = df_old)
   if(!is.null(exclude)) both_tables = exclude_columns(both_tables, exclude)
@@ -50,7 +52,7 @@ compare_df <- function(df_new, df_old, group_col, exclude = NULL, limit_html = 1
 
   check_if_similar_after_unique_and_reorder(both_tables, both_diffs, stop_on_error)
 
-  comparison_table         = create_comparison_table(both_diffs, group_col)
+  comparison_table         = create_comparison_table(both_diffs, group_col, round_output_to)
 
   comparison_table_ts2char = .ts2char(comparison_table)
   comparison_table_diff    = create_comparison_table_diff(comparison_table_ts2char, group_col, tolerance, tolerance_type)
@@ -138,7 +140,7 @@ check_if_similar_after_unique_and_reorder <- function(both_tables, both_diffs, s
 
 }
 
-create_comparison_table <- function(both_diffs, group_col){
+create_comparison_table <- function(both_diffs, group_col, round_output_to){
   message("Creating comparison table...")
   mixed_df = both_diffs$df1_2 %>% mutate(chng_type = NA_integer_) %>% slice(0) %>% data.frame()
   if(nrow(both_diffs$df1_2) != 0) mixed_df = mixed_df %>% rbind(data.frame(chng_type = "1", both_diffs$df1_2))
@@ -146,7 +148,7 @@ create_comparison_table <- function(both_diffs, group_col){
   mixed_df %>%
     arrange(desc(chng_type)) %>% arrange_(group_col) %>%
     # mutate(chng_type = ifelse(chng_type == 1, "1", "2")) %>%
-    select(one_of(group_col), everything()) %>% r2two()
+    select(one_of(group_col), everything()) %>% round_num_cols(round_output_to)
 }
 
 
@@ -204,7 +206,7 @@ check_if_comparable <- function(df_new, df_old, group_col, stop_on_error){
 
 }
 
-r2two <- function(df, round_digits = 2)
+round_num_cols <- function(df, round_digits = 2)
 {
   numeric_cols = which(sapply(df, is.numeric))
   df[, numeric_cols] = lapply(df[, numeric_cols, drop = F], round, round_digits)
@@ -292,7 +294,7 @@ create_change_count <- function(comparison_table_ts2char, group_col){
     mutate(additions = replace(additions, is.na(additions) | additions < 0, 0)) %>%
     mutate(removals = replace(removals, is.na(removals) | removals < 0, 0))
 
-  change_count
+  change_count %>% data.frame()
 
 }
 
